@@ -19,6 +19,7 @@ GetOptions(
     \%options, qw(
         help|h
         man|m
+        hostname=s
 
         spoof
         profile|profiel|basic-profile=i
@@ -63,6 +64,7 @@ if (!$api_key && !$options{spoof}) {
 }
 
 my $api = WebService::KvKAPI->new(
+    $options{hostname} ? (api_host => $options{hostname}) : (),
     $options{spoof} ? (spoof => 1) : ( api_key => $api_key ),
 );
 delete $options{spoof};
@@ -115,7 +117,7 @@ query-kvk.pl - Query the Dutch Chamber of Commerce via the CLI
 
 =head1 VERSION
 
-version 0.104
+version 0.105
 
 =head1 SYNOPSIS
 
@@ -146,6 +148,10 @@ This help
 
 Use the test API from the KvK, does not require an API key
 
+=item * --hostname
+
+Use a different hostname instead of the B<api.kvk.nl>.
+
 =item * --api-key | --apikey | --apiKey
 
 The API key from the KvK
